/*!
 * @certifaction/vue-pdf-viewer 1.1.0
 *
 * @link https://certifaction.com
 * @source https://github.com/certifaction/js-pdf-viewer.git
 * @copyright (c) 2019-2021 Certifaction AG
 * @license MIT
 */
import { mdiMinus, mdiPlus } from '@mdi/js';
import { pdfjsLib, pdfjsViewer } from '@certifaction/pdfjs';

window['pdfjs-dist/build/pdf'] = pdfjsLib;

delete window['pdfjs-dist/build/pdf'];

var i18nWrapperMixin = {
  methods: {
    _$t(key, ...values) {
      if (typeof this.$t === 'function') {
        return this.$t(key, ...values);
      }

      return key;
    },

    _$tc(key, choice, ...values) {
      if (typeof this.$tc === 'function') {
        return this.$tc(key, choice, ...values);
      }

      return key;
    },

    _$te(key, locale) {
      if (typeof this.$te === 'function') {
        return this.$te(key, locale);
      }

      return false;
    },

    _$d(value, ...args) {
      if (typeof this.$d === 'function') {
        return this.$d(value, ...args);
      }

      return false;
    },

    _$n(value, ...args) {
      if (typeof this.$n === 'function') {
        return this.$n(value, ...args);
      }

      return false;
    }

  }
};

//
//
//
//
//
//

var script$1 = {
    name: 'MDIcon',
    props: {
        icon: {
            type: String,
            required: true
        }
    }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

/* script */
const __vue_script__$1 = script$1;

/* template */
var __vue_render__$1 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('svg',{staticClass:"md-icon",attrs:{"viewBox":"0 0 24 24"}},[_c('path',{attrs:{"fill":"currentColor","d":_vm.icon}})])};
var __vue_staticRenderFns__$1 = [];

  /* style */
  const __vue_inject_styles__$1 = undefined;
  /* scoped */
  const __vue_scope_id__$1 = undefined;
  /* module identifier */
  const __vue_module_identifier__$1 = undefined;
  /* functional template */
  const __vue_is_functional_template__$1 = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1 = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__$1, staticRenderFns: __vue_staticRenderFns__$1 },
    __vue_inject_styles__$1,
    __vue_script__$1,
    __vue_scope_id__$1,
    __vue_is_functional_template__$1,
    __vue_module_identifier__$1,
    false,
    undefined,
    undefined,
    undefined
  );

//

const MIN_SCALE = 0.1;
const MAX_SCALE = 10;

var script = {
    name: 'PDFViewer',
    mixins: [
        i18nWrapperMixin
    ],
    components: {
        MDIcon: __vue_component__$1
    },
    props: {
        pdfjsWorkerSrc: {
            type: String,
            required: false
        },
        pdfjsWorkerInstance: {
            type: Worker,
            required: false
        },
        pdfjsCMapUrl: {
            type: String,
            required: true
        },
        url: {
            type: String,
            required: true
        },
        pdfjsViewerOptions: {
            type: Object,
            default: function() {
                return {}
            }
        }
    },
    data() {
        return {
            mdiMinus,
            mdiPlus,
            pdfViewer: null,
            pdfDocument: null,
            scaleOptions: [
                { label: this._$t('pdfViewer.scale.auto'), value: 'auto' },
                { label: this._$t('pdfViewer.scale.pageActual'), value: 'page-actual' },
                { label: this._$t('pdfViewer.scale.pageFit'), value: 'page-fit' },
                { label: this._$t('pdfViewer.scale.pageWidth'), value: 'page-width' },
                { label: '50%', value: 0.5 },
                { label: '75%', value: 0.75 },
                { label: '100%', value: 1 },
                { label: '125%', value: 1.25 },
                { label: '150%', value: 1.5 },
                { label: '200%', value: 2 },
                { label: '300%', value: 3 },
                { label: '400%', value: 4 }
            ],
            currentScale: 'auto',
            customScale: { label: '', value: 0 }
        }
    },
    computed: {
        currentPage() {
            return (this.pdfViewer) ? this.pdfViewer.currentPageNumber : 0
        },
        pageCount() {
            return (this.pdfDocument) ? this.pdfDocument.numPages : 0
        }
    },
    watch: {
        currentScale() {
            this.pdfViewer.currentScaleValue = this.currentScale;
        }
    },
    methods: {
        decreaseScale() {
            let newScale = this.pdfViewer.currentScale;
            newScale -= 0.1;
            newScale = newScale.toFixed(2);
            newScale = Math.floor(newScale * 10) / 10;

            this.currentScale = (newScale < MIN_SCALE) ? MIN_SCALE : newScale;
            this.updateCustomScale();
        },
        increaseScale() {
            let newScale = this.pdfViewer.currentScale;
            newScale += 0.1;
            newScale = newScale.toFixed(2);
            newScale = Math.ceil(newScale * 10) / 10;

            this.currentScale = (newScale > MAX_SCALE) ? MAX_SCALE : newScale;
            this.updateCustomScale();
        },
        updateCustomScale() {
            if (!this.scaleOptions.find(option => option.value === this.currentScale)) {
                this.customScale.label = (this.currentScale * 100).toFixed(0) + '%';
                this.customScale.value = this.currentScale;
            }
        }
    },
    created() {
        if (this.pdfjsWorkerInstance) {
            pdfjsLib.GlobalWorkerOptions.workerPort = this.pdfjsWorkerInstance;
        } else if (this.pdfjsWorkerSrc) {
            pdfjsLib.GlobalWorkerOptions.workerSrc = this.pdfjsWorkerSrc;
        } else {
            throw new Error('PDFViewer: pdfjsWorkerSrc or pdfjsWorkerInstance needs to be defined.')
        }
    },
    async mounted() {
        const eventBus = new pdfjsViewer.EventBus();
        this.pdfViewer = new pdfjsViewer.PDFViewer({
            ...this.pdfjsViewerOptions,
            container: this.$refs.viewerContainer,
            eventBus
        });

        eventBus.on('pagesinit', () => {
            this.pdfViewer.currentScaleValue = this.currentScale;
        });

        const documentLoadingTask = pdfjsLib.getDocument({
            url: this.url,
            cMapUrl: this.pdfjsCMapUrl,
            cMapPacked: true
        });
        this.pdfDocument = await documentLoadingTask.promise;

        this.pdfViewer.setDocument(this.pdfDocument);
    }
};

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"pdf-viewer"},[_c('div',{ref:"viewerContainer",staticClass:"viewer-container"},[_c('div',{staticClass:"viewer"})]),_vm._v(" "),_c('div',{staticClass:"controls"},[_c('div',{staticClass:"pages"},[_vm._v("\n            "+_vm._s(_vm._$t('pdfViewer.page'))+"\n            "),_c('span',{staticClass:"current"},[_vm._v(_vm._s(_vm.currentPage))]),_vm._v(" / "),_c('span',{staticClass:"total"},[_vm._v(_vm._s(_vm.pageCount))])]),_vm._v(" "),_c('div',{staticClass:"scale"},[_c('button',{staticClass:"btn",attrs:{"type":"button"},on:{"click":_vm.decreaseScale}},[_c('MDIcon',{attrs:{"icon":_vm.mdiMinus}})],1),_vm._v(" "),_c('button',{staticClass:"btn",attrs:{"type":"button"},on:{"click":_vm.increaseScale}},[_c('MDIcon',{attrs:{"icon":_vm.mdiPlus}})],1),_vm._v(" "),_c('select',{directives:[{name:"model",rawName:"v-model",value:(_vm.currentScale),expression:"currentScale"}],staticClass:"scale-selector",on:{"change":function($event){var $$selectedVal = Array.prototype.filter.call($event.target.options,function(o){return o.selected}).map(function(o){var val = "_value" in o ? o._value : o.value;return val}); _vm.currentScale=$event.target.multiple ? $$selectedVal : $$selectedVal[0];}}},[_vm._l((_vm.scaleOptions),function(option){return _c('option',{key:option.value,domProps:{"value":option.value}},[_vm._v(_vm._s(option.label)+"\n                ")])}),_vm._v(" "),_c('option',{staticClass:"hidden",attrs:{"disabled":""},domProps:{"value":_vm.customScale.value}},[_vm._v(_vm._s(_vm.customScale.label))])],2)])])])};
var __vue_staticRenderFns__ = [];

  /* style */
  const __vue_inject_styles__ = undefined;
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    undefined,
    undefined,
    undefined
  );

export default __vue_component__;
//# sourceMappingURL=certifaction-vue-pdf-viewer.esm.js.map
